dict

Function dict 

pub fn dict() -> Dictionary
[Dictionary] of buffer text helpers.

Entries:

  • "get_visual_selection": wraps ytil_noxi::visual_selection::get_lines and returns the current visual selection (inclusive) as lines.
  • "get_selection_for_ex_range": returns selected text plus 0-based buffer coordinates for an Ex range.
  • "get_marked_visual_selection": returns persisted visual text plus 0-based buffer coordinates.
  • "get_visual_range_command_prefix": returns the Ex range prefix for a persisted visual range.
  • "get_token_under_cursor": wraps crate::buffer::token_under_cursor::get and returns a classified token under the cursor.

Intended for exposure to Lua.